@@ -51,7 +51,7 @@ our %EXPORT_TAGS = (
     type => [grep m/type_/, @EXPORT_OK],
 );
 
-our $VERSION = '0.39'; # VERSION
+our $VERSION = '0.40'; # VERSION
 
 sub new {
     shift and goto &deduce_deep;
@@ -356,7 +356,7 @@ Data::Object - Object Orientation for Perl 5
 
 =head1 VERSION
 
-version 0.39
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -368,8 +368,9 @@ version 0.39
     extends 'Entity';
     with    'Identity';
 
-    has firstname => is required, ro;
-    has lastname  => is required, ro;
+    alt id => is required, ro;
+
+    has ['firstname', 'lastname'] => is required, ro;
 
     has address1  => is required, rw;
     has address2  => is optional, rw;
@@ -420,13 +421,13 @@ prefixed with the word "type".
 
 =head2 const
 
-    # given 'Exception::Unknown';
+    # given 1.098765;
 
-    const UnknownException => sub { throw 'Exception::Unknown' }
+    const VERSION => 1.098765;
 
 The const function creates a constant function using the name and expression
 supplied to it. A constant function is a function that does not accept any
-arguments and whose result(s) should be deterministic.
+arguments and whose result(s) are deterministic.
 
 =head2 data_array
 
